==> haskell-x509-store-1.6.7-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-88pb0Kevlb9IcsIUnLZPRY
key: x509-store-1.6.7-88pb0Kevlb9IcsIUnLZPRY
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: 6efb99c82fd27f1ae6825362476b8013
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-88pb0Kevlb9IcsIUnLZPRY
depends:
    asn1-encoding-0.9.5-1HooVrxELdT8EXBBjBMSfy
    asn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we
    x509-1.7.5-AGDNqwGGf1H926kJ4arIa9
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.7-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-EzFO9yJnG1QHGExsYjMfxj
key: x509-store-1.6.7-EzFO9yJnG1QHGExsYjMfxj
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: 12c4c699b226ad2e302996bad35d7101
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-EzFO9yJnG1QHGExsYjMfxj
depends:
    asn1-encoding-0.9.5-3LSg3WoNh6O3pQtXpbzGmR
    asn1-types-0.3.2-DLmgLG4DguzLHCJactuvzi base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we
    x509-1.7.5-HSY0xPcI4REFeHDt27wwza
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
